@@ -9,8 +9,8 @@ from wikibaseintegrator.wbi_config import config
 
 
 class FastRunContainer(object):
-    def __init__(self, base_data_type, engine, mediawiki_api_url=None, sparql_endpoint_url=None, wikibase_url=None, base_filter=None, use_refs=False,
-                 ref_handler=None, case_insensitive=False, debug=False):
+    def __init__(self, base_data_type, engine, mediawiki_api_url=None, sparql_endpoint_url=None, wikibase_url=None, base_filter=None, use_refs=False, ref_handler=None,
+                 case_insensitive=False, debug=False):
         self.reconstructed_statements = []
         self.rev_lookup = defaultdict(set)
         self.rev_lookup_ci = defaultdict(set)
@@ -111,7 +111,7 @@ class FastRunContainer(object):
                 if self.debug:
                     print("{} not found in fastrun".format(prop_nr))
                 self.prop_dt_map.update({prop_nr: self.get_prop_datatype(prop_nr)})
-                self._query_data(prop_nr)
+                self._query_data(prop_nr=prop_nr, use_units=date.data_type == 'quantity')
 
             # more sophisticated data types like dates and globe coordinates need special treatment here
             if self.prop_dt_map[prop_nr] == 'time':
@@ -133,11 +133,11 @@ class FastRunContainer(object):
             else:
                 if self.debug:
                     if self.case_insensitive:
-                        print('case insensitive enabled')
+                        print("case insensitive enabled")
                         print(self.rev_lookup_ci)
                     else:
                         print(self.rev_lookup)
-                    print('no matches for rev lookup')
+                    print("no matches for rev lookup")
                 return True
             match_sets.append(temp_set)
 
@@ -150,7 +150,7 @@ class FastRunContainer(object):
         # if not, a write is required no matter what
         if not len(matching_qids) == 1:
             if self.debug:
-                print('no matches ({})'.format(len(matching_qids)))
+                print("no matches ({})".format(len(matching_qids)))
             return True
 
         qid = matching_qids.pop()
@@ -199,7 +199,7 @@ class FastRunContainer(object):
             reconst_props = set([x.get_prop_nr() for x in tmp_rs])
             if (not date.value or not date.data_type) and date.get_prop_nr() in reconst_props:
                 if self.debug:
-                    print('returned from delete prop handling')
+                    print("returned from delete prop handling")
                 return True
             elif not date.value or not date.data_type:
                 # Ignore the deletion statements which are not in the reconstructed statements.
@@ -237,7 +237,7 @@ class FastRunContainer(object):
 
             if self.debug:
                 print("bool_vec: {}".format(bool_vec))
-                print('-----------------------------------')
+                print("-----------------------------------")
                 for x in tmp_rs:
                     if date == x and x.get_prop_nr() not in del_props:
                         print(x.get_prop_nr(), x.get_value(), [z.get_value() for z in x.get_qualifiers()])
@@ -249,19 +249,19 @@ class FastRunContainer(object):
             if not any(bool_vec):
                 if self.debug:
                     print(len(bool_vec))
-                    print('fast run failed at', date.get_prop_nr())
+                    print("fast run failed at", date.get_prop_nr())
                 write_required = True
             else:
                 if self.debug:
-                    print('fast run success')
+                    print("fast run success")
                 tmp_rs.pop(bool_vec.index(True))
 
         if len(tmp_rs) > 0:
             if self.debug:
-                print('failed because not zero')
+                print("failed because not zero")
                 for x in tmp_rs:
-                    print('xxx', x.get_prop_nr(), x.get_value(), [z.get_value() for z in x.get_qualifiers()])
-                print('failed because not zero--END')
+                    print("xxx", x.get_prop_nr(), x.get_value(), [z.get_value() for z in x.get_qualifiers()])
+                print("failed because not zero--END")
             write_required = True
         return write_required
 
@@ -300,8 +300,7 @@ class FastRunContainer(object):
             all_lang_strings = ['']
         return all_lang_strings
 
-    def check_language_data(self, qid: str, lang_data: list, lang: str, lang_data_type: str,
-                            if_exists: str = 'APPEND') -> bool:
+    def check_language_data(self, qid: str, lang_data: list, lang: str, lang_data_type: str, if_exists: str = 'APPEND') -> bool:
         """
         Method to check if certain language data exists as a label, description or aliases
         :param qid: Wikibase item id
@@ -314,13 +313,12 @@ class FastRunContainer(object):
         all_lang_strings = set(x.strip().casefold() for x in self.get_language_data(qid, lang, lang_data_type))
 
         if if_exists == 'REPLACE':
-            return not collections.Counter(all_lang_strings) == collections.Counter(map(lambda x: x.casefold(),
-                                                                                        lang_data))
+            return not collections.Counter(all_lang_strings) == collections.Counter(map(lambda x: x.casefold(), lang_data))
         else:
             for s in lang_data:
                 if s.strip().casefold() not in all_lang_strings:
                     if self.debug:
-                        print('fastrun failed at: {}, string: {}'.format(lang_data_type, s))
+                        print("fastrun failed at: {}, string: {}".format(lang_data_type, s))
                     return True
 
         return False
@@ -363,8 +361,7 @@ class FastRunContainer(object):
             # some difference between RDF and xsd:dateTime that I don't understand
             for value in {'v', 'qval', 'rval'}:
                 if value in i:
-                    if i[value].get("datatype") == 'http://www.w3.org/2001/XMLSchema#dateTime' and not \
-                            i[value]['value'][0] in '+-':
+                    if i[value].get("datatype") == 'http://www.w3.org/2001/XMLSchema#dateTime' and not i[value]['value'][0] in '+-':
                         # if it is a dateTime and doesn't start with plus or minus, add a plus
                         i[value]['value'] = '+' + i[value]['value']
 
@@ -422,11 +419,11 @@ class FastRunContainer(object):
         for i in r:
             qid = i['item']
             if qid not in self.prop_data:
-                self.prop_data[qid] = {prop_nr: dict()}
+                self.prop_data[qid] = {prop_nr: {}}
             if prop_nr not in self.prop_data[qid]:
-                self.prop_data[qid].update({prop_nr: dict()})
+                self.prop_data[qid].update({prop_nr: {}})
             if i['sid'] not in self.prop_data[qid][prop_nr]:
-                self.prop_data[qid][prop_nr].update({i['sid']: dict()})
+                self.prop_data[qid][prop_nr].update({i['sid']: {}})
             # update values for this statement (not including ref)
             d = {'v': i['v']}
             self.prop_data[qid][prop_nr][i['sid']].update(d)
@@ -440,7 +437,7 @@ class FastRunContainer(object):
                     self.prop_data[qid][prop_nr][i['sid']]['qual'].add((i['pq'], i['qval'], '1'))
 
             if 'ref' not in self.prop_data[qid][prop_nr][i['sid']]:
-                self.prop_data[qid][prop_nr][i['sid']]['ref'] = dict()
+                self.prop_data[qid][prop_nr][i['sid']]['ref'] = {}
             if 'ref' in i:
                 if i['ref'] not in self.prop_data[qid][prop_nr][i['sid']]['ref']:
                     self.prop_data[qid][prop_nr][i['sid']]['ref'][i['ref']] = set()
@@ -451,7 +448,7 @@ class FastRunContainer(object):
             if 'unit' in i:
                 self.prop_data[qid][prop_nr][i['sid']]['unit'] = i['unit']
 
-    def _query_data(self, prop_nr: str) -> None:
+    def _query_data(self, prop_nr: str, use_units=False) -> None:
         page_size = 10000
         page_count = 0
         num_pages = None
@@ -468,97 +465,83 @@ class FastRunContainer(object):
 
             r = wbi_core.FunctionsEngine.execute_sparql_query(query, endpoint=self.sparql_endpoint_url)['results']['bindings']
             count = int(r[0]['c']['value'])
-            print('Count: {}'.format(count))
+            print("Count: {}".format(count))
             num_pages = (int(count) // page_size) + 1
             print("Query {}: {}/{}".format(prop_nr, page_count, num_pages))
         while True:
-            if self.use_refs:
-                query = '''
-                    #Tool: wbi_fastrun _query_data_refs
-                    SELECT ?sid ?item ?v ?unit ?pq ?qval ?qunit ?ref ?pr ?rval
-                    WHERE
-                    {{
-                      {base_filter}
+            # Query header
+            query = '''
+            #Tool: wbi_fastrun _query_data
+            SELECT ?sid ?item ?v ?unit ?pq ?qval ?qunit ?ref ?pr ?rval
+            WHERE
+            {{
+            '''
 
-                      # Get amount and unit for the statement
-                      ?item <{wb_url}/prop/{prop_nr}> ?sid .
-                      {{
-                        <{wb_url}/entity/{prop_nr}> wikibase:propertyType ?property_type .
-                        FILTER (?property_type != wikibase:Quantity)
-                        ?sid <{wb_url}/prop/statement/{prop_nr}> ?v .
-                      }}
-                      UNION
-                      {{
-                        ?sid <{wb_url}/prop/statement/value/{prop_nr}> [wikibase:quantityAmount ?v; wikibase:quantityUnit ?unit] .
-                      }}
+            # Base filter
+            query += '''
+            {base_filter}
+            
+            ?item <{wb_url}/prop/{prop_nr}> ?sid .
+            '''
 
-                      # Get qualifiers
-                      OPTIONAL
-                      {{
-                        {{
-                          # Get simple values for qualifiers which are not of type quantity
-                          ?sid ?propQualifier ?qval .
-                          ?pq wikibase:qualifier ?propQualifier .
-                          ?pq wikibase:propertyType ?qualifer_property_type .
-                          FILTER (?qualifer_property_type != wikibase:Quantity)
-                        }}
-                        UNION
-                        {{
-                          # Get amount and unit for qualifiers of type quantity
-                          ?sid ?pqv [wikibase:quantityAmount ?qval; wikibase:quantityUnit ?qunit] .
-                          ?pq wikibase:qualifierValue ?pqv .
-                        }}
-                      }}
-
-                      # get references
-                      OPTIONAL {{
-                        ?sid prov:wasDerivedFrom ?ref .
-                        ?ref ?pr ?rval .
-                        [] wikibase:reference ?pr
-                      }}
-                    }} ORDER BY ?sid OFFSET {offset} LIMIT {page_size}
-                    '''.format(wb_url=self.wikibase_url, base_filter=self.base_filter_string, prop_nr=prop_nr,
-                               offset=str(page_count * page_size), page_size=str(page_size))
+            # Amount and unit
+            if use_units:
+                query += '''
+                {{
+                  <{wb_url}/entity/{prop_nr}> wikibase:propertyType ?property_type .
+                  FILTER (?property_type != wikibase:Quantity)
+                  ?sid <{wb_url}/prop/statement/{prop_nr}> ?v .
+                }}
+                # Get amount and unit for the statement
+                UNION
+                {{
+                  ?sid <{wb_url}/prop/statement/value/{prop_nr}> [wikibase:quantityAmount ?v; wikibase:quantityUnit ?unit] .
+                }}
+                '''
             else:
-                query = '''
-                    #Tool: wbi_fastrun _query_data
-                    SELECT ?sid ?item ?v ?unit ?pq ?qval ?qunit
-                    WHERE
-                    {{
-                      {base_filter}
+                query += '''
+                <{wb_url}/entity/{prop_nr}> wikibase:propertyType ?property_type .
+                ?sid <{wb_url}/prop/statement/{prop_nr}> ?v .
+                '''
 
-                      # Get amount and unit for the statement
-                      ?item <{wb_url}/prop/{prop_nr}> ?sid .
-                      {{
-                        <{wb_url}/entity/{prop_nr}> wikibase:propertyType ?property_type .
-                        FILTER (?property_type != wikibase:Quantity)
-                        ?sid <{wb_url}/prop/statement/{prop_nr}> ?v .
-                      }}
-                      UNION
-                      {{
-                        ?sid <{wb_url}/prop/statement/value/{prop_nr}> [wikibase:quantityAmount ?v; wikibase:quantityUnit ?unit] .
-                      }}
+            # Qualifiers
+            query += '''
+            # Get qualifiers
+            OPTIONAL
+            {{
+              {{
+                # Get simple values for qualifiers which are not of type quantity
+                ?sid ?propQualifier ?qval .
+                ?pq wikibase:qualifier ?propQualifier .
+                ?pq wikibase:propertyType ?qualifer_property_type .
+                FILTER (?qualifer_property_type != wikibase:Quantity)
+              }}
+              UNION
+              {{
+                # Get amount and unit for qualifiers of type quantity
+                ?sid ?pqv [wikibase:quantityAmount ?qval; wikibase:quantityUnit ?qunit] .
+                ?pq wikibase:qualifierValue ?pqv .
+              }}
+            }}
+            '''
 
-                      # Get qualifiers
-                      OPTIONAL
-                      {{
-                        {{
-                          # Get simple values for qualifiers which are not of type quantity
-                          ?sid ?propQualifier ?qval .
-                          ?pq wikibase:qualifier ?propQualifier .
-                          ?pq wikibase:propertyType ?qualifer_property_type .
-                          FILTER (?qualifer_property_type != wikibase:Quantity)
-                        }}
-                        UNION
-                        {{
-                          # Get amount and unit for qualifiers of type quantity
-                          ?sid ?pqv [wikibase:quantityAmount ?qval; wikibase:quantityUnit ?qunit] .
-                          ?pq wikibase:qualifierValue ?pqv .
-                        }}
-                      }}
-                    }} ORDER BY ?sid OFFSET {offset} LIMIT {page_size}
-                    '''.format(wb_url=self.wikibase_url, base_filter=self.base_filter_string, prop_nr=prop_nr,
-                               offset=str(page_count * page_size), page_size=str(page_size))
+            # References
+            if self.use_refs:
+                query += '''
+                # get references
+                OPTIONAL {{
+                  ?sid prov:wasDerivedFrom ?ref .
+                  ?ref ?pr ?rval .
+                  [] wikibase:reference ?pr
+                }}
+                '''
+            # Query footer
+            query += '''
+            }} ORDER BY ?sid OFFSET {offset} LIMIT {page_size}
+            '''
+
+            # Format the query
+            query = query.format(wb_url=self.wikibase_url, base_filter=self.base_filter_string, prop_nr=prop_nr, offset=str(page_count * page_size), page_size=str(page_size))
 
             if self.debug:
                 print(query)
@@ -612,17 +595,16 @@ class FastRunContainer(object):
 
     @lru_cache(maxsize=100000)
     def get_prop_datatype(self, prop_nr: str) -> str:
-        item = self.engine(item_id=prop_nr, sparql_endpoint_url=self.sparql_endpoint_url,
-                           mediawiki_api_url=self.mediawiki_api_url,
-                           wikibase_url=self.wikibase_url, debug=self.debug)
+        item = self.engine(item_id=prop_nr, sparql_endpoint_url=self.sparql_endpoint_url, mediawiki_api_url=self.mediawiki_api_url, wikibase_url=self.wikibase_url,
+                           debug=self.debug)
         return item.entity_metadata['datatype']
 
     def clear(self) -> None:
         """
         convinience function to empty this fastrun container
         """
-        self.prop_dt_map = dict()
-        self.prop_data = dict()
+        self.prop_dt_map = {}
+        self.prop_data = {}
         self.rev_lookup = defaultdict(set)
         self.rev_lookup_ci = defaultdict(set)
 
